unit Auth.dbEntities;

interface

uses
  SysUtils, 
  Generics.Collections, 
  Aurelius.Mapping.Attributes, 
  Aurelius.Types.Blob, 
  Aurelius.Types.DynamicProperties, 
  Aurelius.Types.Nullable, 
  Aurelius.Types.Proxy, 
  Aurelius.Criteria.Dictionary;

type
  TPermission = class;
  TRole = class;
  TRolePermission = class;
  TRoleRole = class;
  TSettings = class;
  TUser = class;
  TUserLog = class;
  TUserRole = class;
  TUserTableDictionary = class;
  TUserLogTableDictionary = class;
  TPermissionTableDictionary = class;
  TRoleTableDictionary = class;
  TRolePermissionTableDictionary = class;
  TRoleRoleTableDictionary = class;
  TUserRoleTableDictionary = class;
  TSettingsTableDictionary = class;
  
  [Entity]
  [Table('t_auth_permissions')]
  [Id('FPermissionId', TIdGenerator.None)]
  TPermission = class
  private
    [Column('pms_id', [TColumnProp.Required])]
    FPermissionId: TGuid;
    
    [Column('pms_code', [TColumnProp.Required])]
    FCode: Integer;
    
    [Column('pms_service', [TColumnProp.Required])]
    FServiceId: TGuid;
    
    [Column('pms_description', [TColumnProp.Required], 200)]
    FDescription: string;
    
    [Column('pms_value', [], 2000)]
    FValue: Nullable<string>;
    
    [Column('pms_operation', [], 200)]
    FOperation: Nullable<string>;
  public
    property PermissionId: TGuid read FPermissionId write FPermissionId;
    property Code: Integer read FCode write FCode;
    property ServiceId: TGuid read FServiceId write FServiceId;
    property Description: string read FDescription write FDescription;
    property Value: Nullable<string> read FValue write FValue;
    property Operation: Nullable<string> read FOperation write FOperation;
  end;
  
  [Entity]
  [Table('t_auth_role')]
  [Id('FRoleID', TIdGenerator.None)]
  TRole = class
  private
    [Column('rol_id', [TColumnProp.Required])]
    FRoleID: TGuid;
    
    [Column('rol_code', [TColumnProp.Required])]
    FCode: Integer;
    
    [Column('rol_system', [TColumnProp.Required])]
    FSystem: Boolean;
    
    [Column('rol_name', [TColumnProp.Required], 80)]
    FName: string;
    
    [ManyValuedAssociation([TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge], 'FRole')]
    FRolePermissionList: TList<TRolePermission>;
    
    [ManyValuedAssociation([TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge], 'FRole')]
    FRoleRoleList: TList<TRoleRole>;
    
    [ManyValuedAssociation([TAssociationProp.Lazy, TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge], 'FRole')]
    FUserRoleList: Proxy<TList<TUserRole>>;
    function GetUserRoleList: TList<TUserRole>;
  public
    constructor Create;
    destructor Destroy; override;
    class function RolePermission(AList: Boolean = True): String;
    class function RoleRole(AList: Boolean = True): String;
    class function UserRole(AList: Boolean = True): String;
    property RoleID: TGuid read FRoleID write FRoleID;
    property Code: Integer read FCode write FCode;
    property System: Boolean read FSystem write FSystem;
    property Name: string read FName write FName;
    property RolePermissionList: TList<TRolePermission> read FRolePermissionList;
    property RoleRoleList: TList<TRoleRole> read FRoleRoleList;
    property UserRoleList: TList<TUserRole> read GetUserRoleList;
  end;
  
  [Entity]
  [Table('t_auth_rol_per')]
  [Id('FRole', TIdGenerator.None)]
  [Id('FPermission', TIdGenerator.None)]
  TRolePermission = class
  private
    [Column('rolper_limitation', [TColumnProp.Required])]
    FLimitation: Integer;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('rol_id', [TColumnProp.Required], 'rol_id')]
    FRole: Proxy<TRole>;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('pms_id', [TColumnProp.Required], 'pms_id')]
    FPermission: Proxy<TPermission>;
    function GetRole: TRole;
    procedure SetRole(const Value: TRole);
    function GetPermission: TPermission;
    procedure SetPermission(const Value: TPermission);
  public
    property Limitation: Integer read FLimitation write FLimitation;
    property Role: TRole read GetRole write SetRole;
    property Permission: TPermission read GetPermission write SetPermission;
  end;
  
  [Entity]
  [Table('t_auth_rol_rol')]
  [Id('FRole', TIdGenerator.None)]
  [Id('FChild', TIdGenerator.None)]
  TRoleRole = class
  private
    [Column('rolrol_limitation', [TColumnProp.Required])]
    FLimitation: Integer;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('rol_id', [TColumnProp.Required], 'rol_id')]
    FRole: Proxy<TRole>;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('rol_child', [TColumnProp.Required], 'rol_id')]
    FChild: Proxy<TRole>;
    function GetRole: TRole;
    procedure SetRole(const Value: TRole);
    function GetChild: TRole;
    procedure SetChild(const Value: TRole);
  public
    property Limitation: Integer read FLimitation write FLimitation;
    property Role: TRole read GetRole write SetRole;
    property Child: TRole read GetChild write SetChild;
  end;
  
  [Entity]
  [Table('t_auth_settings')]
  [Id('FSetID', TIdGenerator.None)]
  TSettings = class
  private
    [Column('set_id', [TColumnProp.Required])]
    FSetID: TGuid;
    
    [Column('set_branch', [TColumnProp.Required])]
    FBranch: Integer;
    
    [Column('set_group', [], 80)]
    FGroup: Nullable<string>;
    
    [Column('set_name', [TColumnProp.Required], 80)]
    FName: string;
    
    [Column('set_value', [TColumnProp.Required], 2000)]
    FValue: string;
    
    [Column('set_datatype', [], 1)]
    FDatatype: Nullable<string>;
    
    [Column('set_label', [], 200)]
    FLabel_: Nullable<string>;
    
    [Column('set_hint', [], 2000)]
    FHint: Nullable<string>;
  public
    property SetID: TGuid read FSetID write FSetID;
    property Branch: Integer read FBranch write FBranch;
    property Group: Nullable<string> read FGroup write FGroup;
    property Name: string read FName write FName;
    property Value: string read FValue write FValue;
    property Datatype: Nullable<string> read FDatatype write FDatatype;
    property Label_: Nullable<string> read FLabel_ write FLabel_;
    property Hint: Nullable<string> read FHint write FHint;
  end;
  
  [Entity]
  [Table('t_auth_user')]
  [UniqueKey('usr_name')]
  [UniqueKey('usr_shortname')]
  [Id('FUserID', TIdGenerator.None)]
  TUser = class
  private
    [Column('usr_id', [TColumnProp.Required])]
    FUserID: TGuid;
    
    [Column('usr_code', [TColumnProp.Required], 20)]
    FCode: string;
    
    [Column('usr_shortname', [TColumnProp.Required], 200)]
    FShortname: string;
    
    [Column('usr_name', [TColumnProp.Required], 200)]
    FName: string;
    
    [Column('usr_pass', [TColumnProp.Required], 2000)]
    FPassword: string;
    
    [Column('usr_autologout', [TColumnProp.Required])]
    FautoLogout: Integer;
    
    [Column('usr_passdate', [])]
    FPassdate: Nullable<TDateTime>;
    
    [Column('usr_validuntil', [])]
    FValidUntil: Nullable<TDateTime>;
    
    [Column('usr_key', [], 32000)]
    FKey: Nullable<string>;
    
    [Column('usr_layout', [], 32000)]
    FLayout: Nullable<string>;
    
    [ManyValuedAssociation([TAssociationProp.Lazy, TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge], 'FUser')]
    FUserLogList: Proxy<TList<TUserLog>>;
    
    [ManyValuedAssociation([TAssociationProp.Lazy, TAssociationProp.Required], [TCascadeType.SaveUpdate, TCascadeType.Merge], 'FUser')]
    FUserRoleList: Proxy<TList<TUserRole>>;
    function GetUserLogList: TList<TUserLog>;
    function GetUserRoleList: TList<TUserRole>;
  public
    constructor Create;
    destructor Destroy; override;
    class function UserLog(AList: Boolean = True): String;
    class function UserRole(AList: Boolean = True): String;
    property UserID: TGuid read FUserID write FUserID;
    property Code: string read FCode write FCode;
    property Shortname: string read FShortname write FShortname;
    property Name: string read FName write FName;
    property Password: string read FPassword write FPassword;
    property autoLogout: Integer read FautoLogout write FautoLogout;
    property Passdate: Nullable<TDateTime> read FPassdate write FPassdate;
    property ValidUntil: Nullable<TDateTime> read FValidUntil write FValidUntil;
    property Key: Nullable<string> read FKey write FKey;
    property Layout: Nullable<string> read FLayout write FLayout;
    property UserLogList: TList<TUserLog> read GetUserLogList;
    property UserRoleList: TList<TUserRole> read GetUserRoleList;
  end;
  
  [Entity]
  [Table('t_auth_userlog')]
  [Id('FUserLogID', TIdGenerator.None)]
  TUserLog = class
  private
    [Column('usl_id', [TColumnProp.Required])]
    FUserLogID: TGuid;
    
    [Column('usl_art', [])]
    FArt: Nullable<Integer>;
    
    [Column('usl_text', [], 200)]
    FText: Nullable<string>;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('usr_id', [TColumnProp.Required], 'usr_id')]
    FUser: Proxy<TUser>;
    function GetUser: TUser;
    procedure SetUser(const Value: TUser);
  public
    property UserLogID: TGuid read FUserLogID write FUserLogID;
    property Art: Nullable<Integer> read FArt write FArt;
    property Text: Nullable<string> read FText write FText;
    property User: TUser read GetUser write SetUser;
  end;
  
  [Entity]
  [Table('t_auth_usr_rol')]
  [Id('FBranch', TIdGenerator.None)]
  [Id('FRole', TIdGenerator.None)]
  [Id('FUser', TIdGenerator.None)]
  TUserRole = class
  private
    [Column('usrrol_branch', [TColumnProp.Required])]
    FBranch: Integer;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('usr_id', [TColumnProp.Required], 'usr_id')]
    FUser: Proxy<TUser>;
    
    [Association([TAssociationProp.Lazy, TAssociationProp.Required], CascadeTypeAll - [TCascadeType.Remove])]
    [JoinColumn('rol_id', [TColumnProp.Required], 'rol_id')]
    FRole: Proxy<TRole>;
    function GetUser: TUser;
    procedure SetUser(const Value: TUser);
    function GetRole: TRole;
    procedure SetRole(const Value: TRole);
  public
    property Branch: Integer read FBranch write FBranch;
    property User: TUser read GetUser write SetUser;
    property Role: TRole read GetRole write SetRole;
  end;
  
  TDicAuthDictionary = class
  private
    FUser: TUserTableDictionary;
    FUserLog: TUserLogTableDictionary;
    FPermission: TPermissionTableDictionary;
    FRole: TRoleTableDictionary;
    FRolePermission: TRolePermissionTableDictionary;
    FRoleRole: TRoleRoleTableDictionary;
    FUserRole: TUserRoleTableDictionary;
    FSettings: TSettingsTableDictionary;
    function GetUser: TUserTableDictionary;
    function GetUserLog: TUserLogTableDictionary;
    function GetPermission: TPermissionTableDictionary;
    function GetRole: TRoleTableDictionary;
    function GetRolePermission: TRolePermissionTableDictionary;
    function GetRoleRole: TRoleRoleTableDictionary;
    function GetUserRole: TUserRoleTableDictionary;
    function GetSettings: TSettingsTableDictionary;
  public
    destructor Destroy; override;
    property User: TUserTableDictionary read GetUser;
    property UserLog: TUserLogTableDictionary read GetUserLog;
    property Permission: TPermissionTableDictionary read GetPermission;
    property Role: TRoleTableDictionary read GetRole;
    property RolePermission: TRolePermissionTableDictionary read GetRolePermission;
    property RoleRole: TRoleRoleTableDictionary read GetRoleRole;
    property UserRole: TUserRoleTableDictionary read GetUserRole;
    property Settings: TSettingsTableDictionary read GetSettings;
  end;
  
  TUserTableDictionary = class
  private
    FUserID: TDictionaryAttribute;
    FCode: TDictionaryAttribute;
    FShortname: TDictionaryAttribute;
    FName: TDictionaryAttribute;
    FPassword: TDictionaryAttribute;
    FautoLogout: TDictionaryAttribute;
    FPassdate: TDictionaryAttribute;
    FValidUntil: TDictionaryAttribute;
    FKey: TDictionaryAttribute;
    FLayout: TDictionaryAttribute;
  public
    constructor Create;
    property UserID: TDictionaryAttribute read FUserID;
    property Code: TDictionaryAttribute read FCode;
    property Shortname: TDictionaryAttribute read FShortname;
    property Name: TDictionaryAttribute read FName;
    property Password: TDictionaryAttribute read FPassword;
    property autoLogout: TDictionaryAttribute read FautoLogout;
    property Passdate: TDictionaryAttribute read FPassdate;
    property ValidUntil: TDictionaryAttribute read FValidUntil;
    property Key: TDictionaryAttribute read FKey;
    property Layout: TDictionaryAttribute read FLayout;
  end;
  
  TUserLogTableDictionary = class
  private
    FUserLogID: TDictionaryAttribute;
    FArt: TDictionaryAttribute;
    FText: TDictionaryAttribute;
    FUser: TDictionaryAssociation;
  public
    constructor Create;
    property UserLogID: TDictionaryAttribute read FUserLogID;
    property Art: TDictionaryAttribute read FArt;
    property Text: TDictionaryAttribute read FText;
    property User: TDictionaryAssociation read FUser;
  end;
  
  TPermissionTableDictionary = class
  private
    FPermissionId: TDictionaryAttribute;
    FCode: TDictionaryAttribute;
    FServiceId: TDictionaryAttribute;
    FDescription: TDictionaryAttribute;
    FValue: TDictionaryAttribute;
    FOperation: TDictionaryAttribute;
  public
    constructor Create;
    property PermissionId: TDictionaryAttribute read FPermissionId;
    property Code: TDictionaryAttribute read FCode;
    property ServiceId: TDictionaryAttribute read FServiceId;
    property Description: TDictionaryAttribute read FDescription;
    property Value: TDictionaryAttribute read FValue;
    property Operation: TDictionaryAttribute read FOperation;
  end;
  
  TRoleTableDictionary = class
  private
    FRoleID: TDictionaryAttribute;
    FCode: TDictionaryAttribute;
    FSystem: TDictionaryAttribute;
    FName: TDictionaryAttribute;
  public
    constructor Create;
    property RoleID: TDictionaryAttribute read FRoleID;
    property Code: TDictionaryAttribute read FCode;
    property System: TDictionaryAttribute read FSystem;
    property Name: TDictionaryAttribute read FName;
  end;
  
  TRolePermissionTableDictionary = class
  private
    FLimitation: TDictionaryAttribute;
    FRole: TDictionaryAssociation;
    FPermission: TDictionaryAssociation;
  public
    constructor Create;
    property Limitation: TDictionaryAttribute read FLimitation;
    property Role: TDictionaryAssociation read FRole;
    property Permission: TDictionaryAssociation read FPermission;
  end;
  
  TRoleRoleTableDictionary = class
  private
    FLimitation: TDictionaryAttribute;
    FRole: TDictionaryAssociation;
    FChild: TDictionaryAssociation;
  public
    constructor Create;
    property Limitation: TDictionaryAttribute read FLimitation;
    property Role: TDictionaryAssociation read FRole;
    property Child: TDictionaryAssociation read FChild;
  end;
  
  TUserRoleTableDictionary = class
  private
    FBranch: TDictionaryAttribute;
    FUser: TDictionaryAssociation;
    FRole: TDictionaryAssociation;
  public
    constructor Create;
    property Branch: TDictionaryAttribute read FBranch;
    property User: TDictionaryAssociation read FUser;
    property Role: TDictionaryAssociation read FRole;
  end;
  
  TSettingsTableDictionary = class
  private
    FSetID: TDictionaryAttribute;
    FBranch: TDictionaryAttribute;
    FGroup: TDictionaryAttribute;
    FName: TDictionaryAttribute;
    FValue: TDictionaryAttribute;
    FDatatype: TDictionaryAttribute;
    FLabel_: TDictionaryAttribute;
    FHint: TDictionaryAttribute;
  public
    constructor Create;
    property SetID: TDictionaryAttribute read FSetID;
    property Branch: TDictionaryAttribute read FBranch;
    property Group: TDictionaryAttribute read FGroup;
    property Name: TDictionaryAttribute read FName;
    property Value: TDictionaryAttribute read FValue;
    property Datatype: TDictionaryAttribute read FDatatype;
    property Label_: TDictionaryAttribute read FLabel_;
    property Hint: TDictionaryAttribute read FHint;
  end;
  
function DicAuth: TDicAuthDictionary;

implementation

var
  __DicAuth: TDicAuthDictionary;

function DicAuth: TDicAuthDictionary;
begin
  if __DicAuth = nil then __DicAuth := TDicAuthDictionary.Create;
  result := __DicAuth
end;

{ TRole }

constructor TRole.Create;
begin
  inherited;
  FRolePermissionList := TList<TRolePermission>.Create;
  FRoleRoleList := TList<TRoleRole>.Create;
  FUserRoleList.SetInitialValue(TList<TUserRole>.Create);
end;

destructor TRole.Destroy;
begin
  FUserRoleList.DestroyValue;
  FRoleRoleList.Free;
  FRolePermissionList.Free;
  inherited;
end;

class function TRole.RolePermission(AList: Boolean = True): String;
begin
  if AList then Result := 'RolePermissionList' else Result := 'RolePermission';
end;

class function TRole.RoleRole(AList: Boolean = True): String;
begin
  if AList then Result := 'RoleRoleList' else Result := 'RoleRole';
end;

function TRole.GetUserRoleList: TList<TUserRole>;
begin
  result := FUserRoleList.Value;
end;

class function TRole.UserRole(AList: Boolean = True): String;
begin
  if AList then Result := 'UserRoleList' else Result := 'UserRole';
end;

{ TRolePermission }

function TRolePermission.GetRole: TRole;
begin
  result := FRole.Value;
end;

procedure TRolePermission.SetRole(const Value: TRole);
begin
  FRole.Value := Value;
end;

function TRolePermission.GetPermission: TPermission;
begin
  result := FPermission.Value;
end;

procedure TRolePermission.SetPermission(const Value: TPermission);
begin
  FPermission.Value := Value;
end;

{ TRoleRole }

function TRoleRole.GetRole: TRole;
begin
  result := FRole.Value;
end;

procedure TRoleRole.SetRole(const Value: TRole);
begin
  FRole.Value := Value;
end;

function TRoleRole.GetChild: TRole;
begin
  result := FChild.Value;
end;

procedure TRoleRole.SetChild(const Value: TRole);
begin
  FChild.Value := Value;
end;

{ TUser }

constructor TUser.Create;
begin
  inherited;
  FUserLogList.SetInitialValue(TList<TUserLog>.Create);
  FUserRoleList.SetInitialValue(TList<TUserRole>.Create);
end;

destructor TUser.Destroy;
begin
  FUserRoleList.DestroyValue;
  FUserLogList.DestroyValue;
  inherited;
end;

function TUser.GetUserLogList: TList<TUserLog>;
begin
  result := FUserLogList.Value;
end;

class function TUser.UserLog(AList: Boolean = True): String;
begin
  if AList then Result := 'UserLogList' else Result := 'UserLog';
end;

function TUser.GetUserRoleList: TList<TUserRole>;
begin
  result := FUserRoleList.Value;
end;

class function TUser.UserRole(AList: Boolean = True): String;
begin
  if AList then Result := 'UserRoleList' else Result := 'UserRole';
end;

{ TUserLog }

function TUserLog.GetUser: TUser;
begin
  result := FUser.Value;
end;

procedure TUserLog.SetUser(const Value: TUser);
begin
  FUser.Value := Value;
end;

{ TUserRole }

function TUserRole.GetUser: TUser;
begin
  result := FUser.Value;
end;

procedure TUserRole.SetUser(const Value: TUser);
begin
  FUser.Value := Value;
end;

function TUserRole.GetRole: TRole;
begin
  result := FRole.Value;
end;

procedure TUserRole.SetRole(const Value: TRole);
begin
  FRole.Value := Value;
end;

{ TDicAuthDictionary }

destructor TDicAuthDictionary.Destroy;
begin
  if FSettings <> nil then FSettings.Free;
  if FUserRole <> nil then FUserRole.Free;
  if FRoleRole <> nil then FRoleRole.Free;
  if FRolePermission <> nil then FRolePermission.Free;
  if FRole <> nil then FRole.Free;
  if FPermission <> nil then FPermission.Free;
  if FUserLog <> nil then FUserLog.Free;
  if FUser <> nil then FUser.Free;
  inherited;
end;

function TDicAuthDictionary.GetUser: TUserTableDictionary;
begin
  if FUser = nil then FUser := TUserTableDictionary.Create;
  result := FUser;
end;

function TDicAuthDictionary.GetUserLog: TUserLogTableDictionary;
begin
  if FUserLog = nil then FUserLog := TUserLogTableDictionary.Create;
  result := FUserLog;
end;

function TDicAuthDictionary.GetPermission: TPermissionTableDictionary;
begin
  if FPermission = nil then FPermission := TPermissionTableDictionary.Create;
  result := FPermission;
end;

function TDicAuthDictionary.GetRole: TRoleTableDictionary;
begin
  if FRole = nil then FRole := TRoleTableDictionary.Create;
  result := FRole;
end;

function TDicAuthDictionary.GetRolePermission: TRolePermissionTableDictionary;
begin
  if FRolePermission = nil then FRolePermission := TRolePermissionTableDictionary.Create;
  result := FRolePermission;
end;

function TDicAuthDictionary.GetRoleRole: TRoleRoleTableDictionary;
begin
  if FRoleRole = nil then FRoleRole := TRoleRoleTableDictionary.Create;
  result := FRoleRole;
end;

function TDicAuthDictionary.GetUserRole: TUserRoleTableDictionary;
begin
  if FUserRole = nil then FUserRole := TUserRoleTableDictionary.Create;
  result := FUserRole;
end;

function TDicAuthDictionary.GetSettings: TSettingsTableDictionary;
begin
  if FSettings = nil then FSettings := TSettingsTableDictionary.Create;
  result := FSettings;
end;

{ TUserTableDictionary }

constructor TUserTableDictionary.Create;
begin
  inherited;
  FUserID := TDictionaryAttribute.Create('UserID');
  FCode := TDictionaryAttribute.Create('Code');
  FShortname := TDictionaryAttribute.Create('Shortname');
  FName := TDictionaryAttribute.Create('Name');
  FPassword := TDictionaryAttribute.Create('Password');
  FautoLogout := TDictionaryAttribute.Create('autoLogout');
  FPassdate := TDictionaryAttribute.Create('Passdate');
  FValidUntil := TDictionaryAttribute.Create('ValidUntil');
  FKey := TDictionaryAttribute.Create('Key');
  FLayout := TDictionaryAttribute.Create('Layout');
end;

{ TUserLogTableDictionary }

constructor TUserLogTableDictionary.Create;
begin
  inherited;
  FUserLogID := TDictionaryAttribute.Create('UserLogID');
  FArt := TDictionaryAttribute.Create('Art');
  FText := TDictionaryAttribute.Create('Text');
  FUser := TDictionaryAssociation.Create('User');
end;

{ TPermissionTableDictionary }

constructor TPermissionTableDictionary.Create;
begin
  inherited;
  FPermissionId := TDictionaryAttribute.Create('PermissionId');
  FCode := TDictionaryAttribute.Create('Code');
  FServiceId := TDictionaryAttribute.Create('ServiceId');
  FDescription := TDictionaryAttribute.Create('Description');
  FValue := TDictionaryAttribute.Create('Value');
  FOperation := TDictionaryAttribute.Create('Operation');
end;

{ TRoleTableDictionary }

constructor TRoleTableDictionary.Create;
begin
  inherited;
  FRoleID := TDictionaryAttribute.Create('RoleID');
  FCode := TDictionaryAttribute.Create('Code');
  FSystem := TDictionaryAttribute.Create('System');
  FName := TDictionaryAttribute.Create('Name');
end;

{ TRolePermissionTableDictionary }

constructor TRolePermissionTableDictionary.Create;
begin
  inherited;
  FLimitation := TDictionaryAttribute.Create('Limitation');
  FRole := TDictionaryAssociation.Create('Role');
  FPermission := TDictionaryAssociation.Create('Permission');
end;

{ TRoleRoleTableDictionary }

constructor TRoleRoleTableDictionary.Create;
begin
  inherited;
  FLimitation := TDictionaryAttribute.Create('Limitation');
  FRole := TDictionaryAssociation.Create('Role');
  FChild := TDictionaryAssociation.Create('Child');
end;

{ TUserRoleTableDictionary }

constructor TUserRoleTableDictionary.Create;
begin
  inherited;
  FBranch := TDictionaryAttribute.Create('Branch');
  FUser := TDictionaryAssociation.Create('User');
  FRole := TDictionaryAssociation.Create('Role');
end;

{ TSettingsTableDictionary }

constructor TSettingsTableDictionary.Create;
begin
  inherited;
  FSetID := TDictionaryAttribute.Create('SetID');
  FBranch := TDictionaryAttribute.Create('Branch');
  FGroup := TDictionaryAttribute.Create('Group');
  FName := TDictionaryAttribute.Create('Name');
  FValue := TDictionaryAttribute.Create('Value');
  FDatatype := TDictionaryAttribute.Create('Datatype');
  FLabel_ := TDictionaryAttribute.Create('Label_');
  FHint := TDictionaryAttribute.Create('Hint');
end;

initialization
{$IFDEF sngAuth}
  RegisterEntity(TUser);
  RegisterEntity(TUserLog);
  RegisterEntity(TPermission);
  RegisterEntity(TRole);
  RegisterEntity(TRolePermission);
  RegisterEntity(TRoleRole);
  RegisterEntity(TUserRole);
  RegisterEntity(TSettings);
{$ENDIF}
finalization
  if __DicAuth <> nil then __DicAuth.Free

end.
